@@ -1,5 +1,5 @@
 package Pugs::Compiler::Rule;
-$Pugs::Compiler::Rule::VERSION = '0.15';
+$Pugs::Compiler::Rule::VERSION = '0.16';
 
 # Documentation in the __END__
 use 5.006;
@@ -102,70 +102,6 @@ to several other modules:
 
 =back
 
-=head2 Implemented Features
-
-  <ws> 
-  #comment\n 
-  . 
-  ? * + *? +? ??
-  literal
-  [] 
-  ()     
-  |
- 
-  <'literal'>
-  <subrule>
-  <namespace::subrule>
-  <$var>      
-  <?subrule>
-  <!subrule>
-  <before ...>
-  <after ...>         -- implemented in :ratchet mode only
-  <subrule('param')>  -- constant parameters only
- 
-  %hash
- 
-  <@var>             -- special-cased for array-of-rule (but not Rule|Str)
-  \char              -- not all chars implemented
-  {code}             -- non-capturing closure
-                     -- perl5 syntax inside closure
-                     -- $/ doesn't work yet
-  { return code }    -- capturing closure
-                     -- perl5 syntax inside closure
-                     -- $/ works
-  $var := (capture)  -- capture aliasing
-  $<> $/<>           -- special variables can't be used inside a match yet
-  $/ 
-  $<0> $<1>
-  $0 $1
-  \n \N
-  $^a $^b            -- positional parameters (must start with $^a)
-  ^ $
-  :
-
-=head2 Unimplemented or untested features
-
-  $variable 
-  @variable
-  $/<0> $/<1>
-  $/0 $/1
-  <"literal">
-  ^^ $$
-  <unicode-class> <+unicode-class> <+unicode-class+unicode-class>
-  <&var> 
-  <%var>
-  **{n..m}
-  :: :::   (commit)
-  $var := [non-capture]
-  $var := <rule>
-  <(closure-assertion)> <{code-returns-rule}>
-  <<character-class>> <[character-class]>
-  :flag :flag() :flag[]
-  \x0a \0123 ...
-  &    
-  $1      - lvalue match variables
-  $/ $()  - global match variables 
-
 =head1 METHODS
 
 =over
